from __future__ import absolute_import, division, print_function

__version__ = "0.5.0"
dependencies = ["restnavigator==1.0.1",
                "requests[socks]==2.13.0",
                "configparser==3.5.0"]
